@@ -1,50 +1,4 @@
 # Plugins for the occ function for each data source
-## helper functions
-move_cols <- function(x, y)
-  x[ c(y, names(x)[-sapply(y, function(z) grep(paste0('\\b', z, '\\b'), names(x)))]) ]
-
-emptylist <- function(opts) list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
-
-stand_latlon <- function(x){
-  lngs <- c('decimalLongitude', 'decimallongitude', 'Longitude', 'lng', 'longitude', 
-            'decimal_longitude', 'geopoint.lon')
-  lats <- c('decimalLatitude', 'decimallatitude', 'Latitude', 'lat', 'latitude', 
-            'decimal_latitude', 'geopoint.lat')
-  names(x)[ names(x) %in% lngs ] <- 'longitude'
-  names(x)[ names(x) %in% lats ] <- 'latitude'
-  x
-}
-
-add_latlong_if_missing <- function(x) {
-  if (is.null(x$longitude)) x$longitude <- NA
-  if (is.null(x$latitude)) x$latitude <- NA
-  return(x)
-}
-
-stand_dates <- function(dat, from){
-  datevars <- list(gbif = 'eventDate', bison = c('eventDate', 'year'), inat = 'datetime',
-                   ebird = 'obsDt', ecoengine = 'begin_date', vertnet = 'eventdate', 
-                   idigbio = 'datecollected')
-  var <- datevars[[from]]
-  if (from == "bison") {
-    var <- if ( is.null(dat$eventDate) ) "year" else "eventDate"
-  }
-  if ( is.null(dat[[var]]) ) {
-    dat
-  } else {
-    dat[[var]] <- switch(from,
-                         gbif = ymd_hms(dat[[var]], truncated = 3, quiet = TRUE),
-                         bison = ydm_hm(dat[[var]], truncated = 6, quiet = TRUE),
-                         inat = ymd_hms(dat[[var]], truncated = 3, quiet = TRUE),
-                         ebird = ymd_hm(dat[[var]], truncated = 3, quiet = TRUE),
-                         ecoengine = ymd(dat[[var]], truncated = 3, quiet = TRUE),
-                         vertnet = ymd(dat[[var]], truncated = 3, quiet = TRUE),
-                         idigbio = ymd_hms(dat[[var]], truncated = 3, quiet = TRUE)
-    )
-    if (from == "bison") rename(dat, setNames('date', var)) else dat
-  }
-}
-
 ## the plugins
 #' @noRd
 foo_gbif <- function(sources, query, limit, start, geometry, has_coords, callopts, opts) {
@@ -119,12 +73,12 @@ foo_ecoengine <- function(sources, query, limit, page, geometry, has_coords, cal
     time <- now()
     opts$georeferenced <- has_coords
     opts$scientific_name <- query
-    opts$georeferenced <- TRUE
+    #opts$georeferenced <- TRUE
     if (!'page_size' %in% names(opts)) opts$page_size <- limit
     if (!'page' %in% names(opts)) opts$page <- page
     if (!is.null(geometry)) {
       opts$bbox <- if (grepl('POLYGON', paste(as.character(geometry), collapse = " "))) {
-        wkt2bbox(geometry) 
+        paste0(wkt2bbox(geometry), collapse = ",")
       } else {
         geometry 
       }
@@ -139,9 +93,11 @@ foo_ecoengine <- function(sources, query, limit, page, geometry, has_coords, cal
     opts$quiet <- TRUE
     opts$progress <- FALSE
     opts$foptions <- callopts
-    out_ee <- tryCatch(do.call(ee_observations, opts), error = function(e) e)
+    out_ee <- tryCatch(do.call(ee_observations2, opts), error = function(e) e)
     if (out_ee$results == 0 || is(out_ee, "simpleError")) {
-      warning(sprintf("No records found in Ecoengine for %s", query), call. = FALSE)
+      warning(sprintf("No records found in Ecoengine for %s", 
+        if (is.null(query)) paste0(substr(geometry, 1, 20), ' ...') else query
+      ), call. = FALSE)
       list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
     } else{
       out <- out_ee$data
@@ -167,21 +123,21 @@ foo_antweb <- function(sources, query, limit, start, geometry, has_coords, callo
     opts$georeferenced <- has_coords
     # limit <- NULL
     geometry <- NULL
-
+    
     query <- sub("^ +", "", query)
     query <- sub(" +$", "", query)
-
+    
     if (length(strsplit(query, " ")[[1]]) == 2) {
       opts$scientific_name <- query
     } else {
       opts$genus <- query
       opts$scientific_name <- NULL
     }
-
+    
     if (!'limit' %in% names(opts)) opts$limit <- limit
     if (!'offset' %in% names(opts)) opts$offset <- start
     out <- tryCatch(do.call(aw_data, opts), error = function(e) e)
-
+    
     if (is.null(out) || is(out, "simpleError")) {
       warning(sprintf("No records found in AntWeb for %s", query), call. = FALSE)
       list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
@@ -218,10 +174,10 @@ foo_bison <- function(sources, query, limit, start, geometry, callopts, opts) {
         bisonfxn <- "bison"
       }
     }
-
+    
     time <- now()
     opts$verbose <- FALSE
-
+    
     if (bisonfxn == "bison") {
       if (!'count' %in% names(opts)) opts$count <- limit
       opts$config <- callopts
@@ -230,7 +186,7 @@ foo_bison <- function(sources, query, limit, start, geometry, callopts, opts) {
       opts$callopts <- callopts
     }
     if (!'start' %in% names(opts)) opts$start <- start
-
+    
     if (!is.null(geometry)) {
       opts$aoi <- if (grepl('POLYGON', paste(as.character(geometry), collapse = " "))) {
         geometry
@@ -421,27 +377,3 @@ foo_idigbio <- function(sources, query, limit, start, geometry, has_coords, call
     list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
   }
 }
-
-limit_alias <- function(x, sources, geometry=NULL){
-  bisonvar <- if (is.null(geometry)) 'rows' else 'count'
-  if (length(x) != 0) {
-    lim_name <- switch(sources, ecoengine = "page_size", bison = bisonvar, inat = "maxresults", ebird = "max")
-    if ("limit" %in% names(x)) {
-      names(x)[ which(names(x) == "limit") ] <- lim_name
-      x
-    } else {
-      x
-    }
-  } else {
-    x
-  }
-}
-
-add_latlong <- function(x, nms) {
-  for (i in seq_along(nms)) {
-    if (!nms[[i]] %in% names(x)) {
-      x[[nms[[i]]]] <- NA
-    }
-  }
-  return(x)
-}
